@@ -42,8 +42,89 @@
 #' This can cause problems, e.g., when using these geometries as input argument
 #' to [sf::st_interpolate_aw()]. `make_valid = TRUE` makes sure that
 #' only valid (multi-)polygons are returned, example included below.
+#' 
+#' The objects downloaded from GISCO should contain all or some of the 
+#' following variable columns:
+#' * **id**: JSON id code, the same as NUTS_ID. See NUTS_ID below for further clarification.
+#' * **LEVL_CODE**: NUTS level code: 0 (national level), 1 (major socio-economic regions), 2 (basic regions for the application of regional policies) or 3 (small regions).
+#' * **NUTS_ID**: NUTS ID code, consisting of country code and numbers (1 for NUTS 1, 2 for NUTS 2 and 3 for NUTS 3)
+#' * **CNTR_CODE**: Country code: two-letter ISO code (ISO 3166 alpha-2), except in the case of Greece (EL).
+#' * **NAME_LATN**: NUTS name in local language, transliterated to Latin script
+#' * **NUTS_NAME**: NUTS name in local language, in local script.
+#' * **MOUNT_TYPE**: Mountain typology for NUTS 3 regions.
+#' \itemize{
+#'   \item{1: "where more than 50 % of the surface is covered by topographic mountain areas"}
+#'   \item{2: "in which more than 50 % of the regional population lives in topographic mountain areas"}
+#'   \item{3: "where more than 50 % of the surface is covered by topographic mountain areas and where more than 50 % of the regional population lives in these mountain areas"} 
+#'   \item{4: non-mountain region / other region}
+#'   \item{0: no classification provided (e.g. in the case of NUTS 1 and NUTS 2 and non-EU countries)}
+#' }
+#' * **URBN_TYPE**: Urban-rural typology for NUTS 3 regions.
+#' \itemize{
+#'   \item{1: predominantly urban region}
+#'   \item{2: intermediate region}
+#'   \item{3: predominantly rural region}
+#'   \item{0: no classification provided (e.g. in the case of NUTS 1 and NUTS 2 regions)}
+#' }
+#' * **COAST_TYPE**: Coastal typology for NUTS 3 regions. 
+#' \itemize{
+#'   \item{1: coastal (on coast)}
+#'   \item{2: coastal (>= 50% of population living within 50km of the coastline)}
+#'   \item{3: non-coastal region}
+#'   \item{0: no classification provided (e.g. in the case of NUTS 1 and NUTS 2 regions)}
+#' }
+#' * **FID**: Same as NUTS_ID.
+#' * **geometry**: geospatial information.
+#' * **geo**: Same as NUTS_ID, added for for easier joins with dplyr. However, it is recommended to use other identical fields for this purpose.
+#' 
 #' @author Markus Kainu <markuskainu@gmail.com>
 #' @return a sf, data_frame or SpatialPolygonDataFrame.
+#' 
+#' @source 
+#' Data source: Eurostat
+#' 
+#' © EuroGeographics for the administrative boundaries
+#' 
+#' Data downloaded from: \url{https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/administrative-units-statistical-units}
+#' @references 
+#' The following copyright notice is provided for end user convenience. 
+#' Please check up-to-date copyright information from the eurostat website:
+#' [GISCO: Geographical information and maps - Administrative units/statistical units](https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/administrative-units-statistical-units)
+#' 
+#' "In addition to the [general copyright and licence policy](https://ec.europa.eu/eurostat/web/main/about/policies/copyright) applicable to the whole Eurostat website, the following specific provisions apply to the datasets you are downloading. The download and usage of these data is subject to the acceptance of the following clauses:
+#' 
+#' 1. The Commission agrees to grant the non-exclusive and not transferable
+#' right to use and process the Eurostat/GISCO geographical data downloaded
+#' from this page (the "data").
+#' 
+#' 1. The permission to use the data is granted on condition that:
+#' \enumerate{
+#'   \item{the data will not be used for commercial purposes;}
+#'   \item{the source will be acknowledged. A copyright notice, as specified 
+#'   below, will have to be visible on any printed or electronic publication 
+#'   using the data downloaded from this page.}
+#' }
+#' ## Copyright notice
+#' 
+#' When data downloaded from this page is used in any printed or electronic
+#' publication, in addition to any other provisions applicable to the whole
+#' Eurostat website, data source will have to be acknowledged in the legend of
+#' the map and in the introductory page of the publication with the following
+#' copyright notice:
+#' 
+#' EN: © EuroGeographics for the administrative boundaries
+#' 
+#' FR: © EuroGeographics pour les limites administratives
+#' 
+#' DE: © EuroGeographics bezüglich der Verwaltungsgrenzen
+#' 
+#' For publications in languages other than English, French or German, the 
+#' translation of the copyright notice in the language of the publication shall
+#' be used.
+#' 
+#' If you intend to use the data commercially, please contact EuroGeographics 
+#' for information regarding their licence agreements."
+#' 
 #' @family geospatial
 #' @examples
 #' \donttest{
@@ -103,8 +184,9 @@
 #'
 #' @importFrom utils data
 #' @importFrom broom tidy
-#' @importFrom httr http_error content
+#' @importFrom httr http_error content RETRY
 #' @importFrom methods as
+#' @importFrom dplyr left_join
 #'
 #' @export
 get_eurostat_geospatial <- function(output_class = "sf",
@@ -224,7 +306,7 @@ get_eurostat_geospatial <- function(output_class = "sf",
         nuts_sp <- as(shp, "Spatial")
         nuts_sp$id <- row.names(nuts_sp)
         nuts_ff <- broom::tidy(nuts_sp)
-        shp <- left_join(nuts_ff, nuts_sp@data)
+        shp <- dplyr::left_join(nuts_ff, nuts_sp@data)
       } else if (output_class == "spdf") {
         shp <- methods::as(shp, "Spatial")
       }
@@ -255,43 +337,43 @@ get_eurostat_geospatial <- function(output_class = "sf",
 
         if (nuts_level %in% c("0", "all")) {
           url <- paste0(burl, resolution, "M_", year, "_", crs, "_LEVL_0.geojson")
-          resp <- RETRY("GET", url, terminate_on = c(404))
+          resp <- httr::RETRY("GET", url, terminate_on = c(404))
           if (httr::http_error(resp)) {
             stop(paste("The requested url cannot be found within
           the get_eurostat_geospatial function:", url))
           } else {
-            nuts0 <- sf::st_read(httr::content(resp, as = "text"),
+            nuts0 <- sf::st_read(httr::content(resp, as = "text", encoding = "UTF-8"),
               stringsAsFactors = FALSE, quiet = TRUE
             )
           }
         }
         if (nuts_level %in% c("1", "all")) {
           url <- paste0(burl, resolution, "M_", year, "_", crs, "_LEVL_1.geojson")
-          resp <- RETRY("GET", url, terminate_on = c(404))
+          resp <- httr::RETRY("GET", url, terminate_on = c(404))
           if (httr::http_error(resp)) {
             stop(paste("The requested url cannot be found within the get_eurostat_geospatial function:", url))
           } else {
-            nuts1 <- sf::st_read(httr::content(resp, as = "text"),
+            nuts1 <- sf::st_read(httr::content(resp, as = "text", encoding = "UTF-8"),
               stringsAsFactors = FALSE, quiet = TRUE
             )
           }
         }
         if (nuts_level %in% c("2", "all")) {
-          resp <- RETRY("GET", paste0(burl, resolution, "M_", year, "_", crs, "_LEVL_2.geojson"), terminate_on = c(404))
+          resp <- httr::RETRY("GET", paste0(burl, resolution, "M_", year, "_", crs, "_LEVL_2.geojson"), terminate_on = c(404))
           if (httr::http_error(resp)) {
             stop(paste("The requested url cannot be found within the get_eurostat_geospatial function:", url))
           } else {
-            nuts2 <- sf::st_read(httr::content(resp, as = "text"),
+            nuts2 <- sf::st_read(httr::content(resp, as = "text", encoding = "UTF-8"),
               stringsAsFactors = FALSE, quiet = TRUE
             )
           }
         }
         if (nuts_level %in% c("3", "all")) {
-          resp <- RETRY("GET", paste0(burl, resolution, "M_", year, "_", crs, "_LEVL_3.geojson"), terminate_on = c(404))
+          resp <- httr::RETRY("GET", paste0(burl, resolution, "M_", year, "_", crs, "_LEVL_3.geojson"), terminate_on = c(404))
           if (httr::http_error(resp)) {
             stop(paste("The requested url cannot be found within the get_eurostat_geospatial function:", url))
           } else {
-            nuts3 <- sf::st_read(httr::content(resp, as = "text"),
+            nuts3 <- sf::st_read(httr::content(resp, as = "text", encoding = "UTF-8"),
               stringsAsFactors = FALSE, quiet = TRUE
             )
           }
